

set -ex



test -f $PREFIX/lib/libgpr.so
test ! -f $PREFIX/lib/libgpr.a
test -f $PREFIX/lib/libgrpc.so
test ! -f $PREFIX/lib/libgrpc.a
test -f $PREFIX/lib/libgrpc_unsecure.so
test ! -f $PREFIX/lib/libgrpc_unsecure.a
test -f $PREFIX/lib/libgrpc++.so
test ! -f $PREFIX/lib/libgrpc++.a
test -f $PREFIX/lib/libgrpc++_unsecure.so
test ! -f $PREFIX/lib/libgrpc++_unsecure.a
test -f $PREFIX/lib/libaddress_sorting.so
test ! -f $PREFIX/lib/libaddress_sorting.a
test -f $PREFIX/lib/libupb.so
test ! -f $PREFIX/lib/libupb.a
test -f $PREFIX/bin/grpc_cpp_plugin
test -f $PREFIX/bin/grpc_csharp_plugin
test -f $PREFIX/bin/grpc_node_plugin
test -f $PREFIX/bin/grpc_objective_c_plugin
test -f $PREFIX/bin/grpc_php_plugin
test -f $PREFIX/bin/grpc_python_plugin
test -f $PREFIX/bin/grpc_ruby_plugin
pkg-config --print-errors --exact-version "26.0.0" gpr
pkg-config --print-errors --exact-version "26.0.0" grpc
pkg-config --print-errors --exact-version "26.0.0" grpc_unsecure
pkg-config --print-errors --exact-version "1.48.2" grpc++
pkg-config --print-errors --exact-version "1.48.2" grpc++_unsecure
./test_grpc.sh
exit 0
